


============
Random Utils
============


.. automodule:: npdl.utils.random

.. currentmodule:: npdl.utils


.. autofunction:: get_rng
.. autofunction:: set_rng
.. autofunction:: set_seed
.. autofunction:: get_dtype
.. autofunction:: set_dtype
